# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csensor.proto\x12\rSensorPackage\"\x15\n\x13SensorCommonRequest\"1\n\x14SensorCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\")\n\x15\x44istanceSensorRequest\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\"5\n\x12\x44istanceSensorInfo\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"d\n\x16\x44istanceSensorResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12/\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32!.SensorPackage.DistanceSensorInfo\"\xd5\x01\n\rIMUSensorInfo\x12\x0e\n\x06gyro_x\x18\x01 \x01(\x02\x12\x0e\n\x06gyro_y\x18\x02 \x01(\x02\x12\x0e\n\x06gyro_z\x18\x03 \x01(\x02\x12\x0f\n\x07\x61\x63\x63\x65l_x\x18\x04 \x01(\x02\x12\x0f\n\x07\x61\x63\x63\x65l_y\x18\x05 \x01(\x02\x12\x0f\n\x07\x61\x63\x63\x65l_z\x18\x06 \x01(\x02\x12\x11\n\tcompass_x\x18\x07 \x01(\x02\x12\x11\n\tcompass_y\x18\x08 \x01(\x02\x12\x11\n\tcompass_z\x18\t \x01(\x02\x12\x0c\n\x04roll\x18\n \x01(\x02\x12\r\n\x05pitch\x18\x0b \x01(\x02\x12\x0b\n\x03yaw\x18\x0c \x01(\x02\"Z\n\x11IMUSensorResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1c.SensorPackage.IMUSensorInfo\"\x17\n\x15StartCalibrateRequest\"P\n\x16StartCalibrateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04step\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\"\x18\n\x16\x43\x61ncelCalibrateRequest\"4\n\x17\x43\x61ncelCalibrateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x15\n\x13\x41ttitudeTiltRequest\"\xb6\x01\n\x14\x41ttitudeTiltResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x14\n\x0ctilt_forward\x18\x03 \x01(\x08\x12\x11\n\ttilt_back\x18\x04 \x01(\x08\x12\x11\n\ttilt_left\x18\x05 \x01(\x08\x12\x12\n\ntilt_right\x18\x06 \x01(\x08\x12\x0f\n\x07\x66\x61\x63\x65_up\x18\x07 \x01(\x08\x12\x11\n\tface_down\x18\x08 \x01(\x08\x12\x0f\n\x07shaking\x18\t \x01(\x08\x32\xc4\x06\n\x11SensorServiceGrpc\x12g\n\x16getDistanceSensorValue\x12$.SensorPackage.DistanceSensorRequest\x1a%.SensorPackage.DistanceSensorResponse\"\x00\x12l\n\x19startDistanceSensorStream\x12$.SensorPackage.DistanceSensorRequest\x1a%.SensorPackage.DistanceSensorResponse\"\x00\x30\x01\x12g\n\x18stopDistanceSensorStream\x12$.SensorPackage.DistanceSensorRequest\x1a#.SensorPackage.SensorCommonResponse\"\x00\x12[\n\x11getIMUSensorValue\x12\".SensorPackage.SensorCommonRequest\x1a .SensorPackage.IMUSensorResponse\"\x00\x12\x61\n\x0estartCalibrate\x12$.SensorPackage.StartCalibrateRequest\x1a%.SensorPackage.StartCalibrateResponse\"\x00\x30\x01\x12\x62\n\x0f\x63\x61ncelCalibrate\x12%.SensorPackage.CancelCalibrateRequest\x1a&.SensorPackage.CancelCalibrateResponse\"\x00\x12\\\n\x0fgetAttitudeTilt\x12\".SensorPackage.AttitudeTiltRequest\x1a#.SensorPackage.AttitudeTiltResponse\"\x00\x12m\n\x1a\x63\x61librateIMUWithAVFeedback\x12$.SensorPackage.StartCalibrateRequest\x1a%.SensorPackage.StartCalibrateResponse\"\x00\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sensor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SENSORCOMMONREQUEST._serialized_start=31
  _SENSORCOMMONREQUEST._serialized_end=52
  _SENSORCOMMONRESPONSE._serialized_start=54
  _SENSORCOMMONRESPONSE._serialized_end=103
  _DISTANCESENSORREQUEST._serialized_start=105
  _DISTANCESENSORREQUEST._serialized_end=146
  _DISTANCESENSORINFO._serialized_start=148
  _DISTANCESENSORINFO._serialized_end=201
  _DISTANCESENSORRESPONSE._serialized_start=203
  _DISTANCESENSORRESPONSE._serialized_end=303
  _IMUSENSORINFO._serialized_start=306
  _IMUSENSORINFO._serialized_end=519
  _IMUSENSORRESPONSE._serialized_start=521
  _IMUSENSORRESPONSE._serialized_end=611
  _STARTCALIBRATEREQUEST._serialized_start=613
  _STARTCALIBRATEREQUEST._serialized_end=636
  _STARTCALIBRATERESPONSE._serialized_start=638
  _STARTCALIBRATERESPONSE._serialized_end=718
  _CANCELCALIBRATEREQUEST._serialized_start=720
  _CANCELCALIBRATEREQUEST._serialized_end=744
  _CANCELCALIBRATERESPONSE._serialized_start=746
  _CANCELCALIBRATERESPONSE._serialized_end=798
  _ATTITUDETILTREQUEST._serialized_start=800
  _ATTITUDETILTREQUEST._serialized_end=821
  _ATTITUDETILTRESPONSE._serialized_start=824
  _ATTITUDETILTRESPONSE._serialized_end=1006
  _SENSORSERVICEGRPC._serialized_start=1009
  _SENSORSERVICEGRPC._serialized_end=1845
# @@protoc_insertion_point(module_scope)



import logging
import sys,os
sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
import json
from ugot.grpc_pb import audio_pb2,audio_pb2_grpc
from base_client import GrpcClient

class AudioClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = audio_pb2_grpc.AudioServiceGrpcStub(channel=self.channel)

    def setAudioAsr(self, begin_vad = 3000, end_vad = 1500, duration = 60000):

        input_data = audio_pb2.AudioAsrRequest()
        input_data.begin_vad = begin_vad
        input_data.end_vad = end_vad
        input_data.duration = duration

        response = self.client.setAudioAsr(input_data)
        return response

    def setAudioTts(self, text, voice_type):

        input_data = audio_pb2.AudioTtsRequest()
        input_data.text = text
        input_data.voice_type = voice_type  # 声音类型 0-女声，1-男声

        response = self.client.setAudioTts(input_data)
        return response

    def setAudioNlp(self, text):

        input_data = audio_pb2.AudioNlpRequest()
        input_data.text = text

        response = self.client.setAudioNlp(input_data)
        return response

    def playAudioFile(self, audio_file, audio_type):

        input_data = audio_pb2.AudioPlayRequest()
        input_data.audio_type = audio_type  # 0 表示上传音频, 1 表示录音,2 表示内部音效
        if isinstance(audio_file, str):
            input_data.audio_file = audio_file
        elif isinstance(audio_file, tuple):
            input_data.audio_file = '/'.join(audio_file)

        response = self.client.playAudioFile(input_data)
        return response

    def stopPlayAudio(self):

        input_data = audio_pb2.AudioEmptyRequest()

        response = self.client.stopPlayAudio(input_data)
        return response

    def getDirectionOfAudio(self):

        input_data = audio_pb2.AudioDirectionRequest()
        input_data.duration = 3000

        response = self.client.getDirectionOfAudio(input_data)
        return response

    def enableAudioDirection(self):

        input_data = audio_pb2.AudioEmptyRequest()

        response = self.client.enableAudioDirection(input_data)
        return response

    def disableAudioDirection(self):

        input_data = audio_pb2.AudioEmptyRequest()

        response = self.client.disableAudioDirection(input_data)
        return response

    def __del__(self):
        # # 销毁时候停止所有声音
        try:
            self.stopPlayAudio()
        except Exception as e:
            print('audio stopPlayAudio error:')
        pass



import logging
import sys, os

sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import network_pb2, network_pb2_grpc
from base_client import GrpcClient
from ugot.src.enum import E_Joypad
import json

class NetworkClient(GrpcClient):
    last_seq = -1
    last_msg = ''

    def __init__(self, address):
        super().__init__(address)

        self.client = network_pb2_grpc.NetworkServiceGrpcStub(channel=self.channel)

    ### 物联网
    def set_message_param(self, seq, msg):
        self.last_seq = seq
        self.last_msg = msg

    def check_same_message(self, seq, msg):
        if self.last_seq == seq and self.last_msg == msg:
            return True
        return False

    def setBrocastEnable(self, enable):
        input_data = network_pb2.SetBrocastEnableRequest()
        input_data.enable = enable

        response = self.client.setBrocastEnable(input_data)
        return response

    def setBrocastPort(self, nPort):
        input_data = network_pb2.SetBrocastPortRequest()
        input_data.nPort = str(nPort)

        response = self.client.setBrocastPort(input_data)
        return response

    def sendBrocastMsg(self, stMsg):
        input_data = network_pb2.SendBrocastMsgRequest()
        input_data.stMsg = str(stMsg)

        response = self.client.sendBrocastMsg(input_data)
        return response

    def getReceivedBrocastMsg(self):
        input_data = network_pb2.NetworkCommonRequest()

        response = self.client.getReceivedBrocastMsg(input_data)

        if response.code == 0:
            #  {"seq":1,"value":"你好1"}
            if not len(response.received_message):
                # 未收到消息
                self.set_message_param(-1, '')
                return self.last_msg
            try:
                import json
                data = json.loads(response.received_message)
                if data is None:
                    self.set_message_param(-1, '')
                    return self.last_msg

                seq = data['seq']
                value = data['value']

                if self.check_same_message(seq, value):
                    return ''
                else:
                    self.set_message_param(seq, value)
                    return self.last_msg
            except Exception as e:
                # LOG.addPythonLog(1, e)
                # assert ()
                logging.error('getReceivedBrocastMsg error!!')
        return ''

    ### WI-FI

    def getWifiStatus(self):
        input_data = network_pb2.NetworkCommonRequest()
        response = self.client.getWifiStatus(input_data)
        return response


    ### 手柄

    def getBTJoypadStatus(self):
        """获取蓝牙手柄点击状态
        """
        input_data = network_pb2.NetworkCommonRequest()

        response = self.client.getBTJoypadStatus(input_data)
        response = response.status

        # response = '{"stick": {"l": {"x": 100, "y": 100}, "r": {"x": 50, "y": 0}}, "arrow": {"l": 0, "r": 0, "u": 0, "d": 0}, "function": {"start": 0, "power": 0, "bt": 0}, "addition": {"l1": 0, "l2": 0, "l3": 0, "r1": 0, "r2": 0, "r3": 0}, "button": {"a": 1, "b": 0, "x": 0, "y": 0}}'
        return response

    # 获取当前点下的按钮
    def get_joypad_button_state(self):

        result = self.getBTJoypadStatus()

        if result is None or len(result) == 0:
            # 没有获取到事件
            return []

        data = json.loads(result)
        if data is None:
            return []

        pressed_btns = []
        arrow = data['arrow']
        if arrow['l'] == 1:
            pressed_btns.append(E_Joypad.L)
        if arrow['r'] == 1:
            pressed_btns.append(E_Joypad.R)
        if arrow['u'] == 1:
            pressed_btns.append(E_Joypad.U)
        if arrow['d'] == 1:
            pressed_btns.append(E_Joypad.D)

        function = data['function']

        addition = data['addition']
        if addition['l1'] == 1:
            pressed_btns.append(E_Joypad.L1)
        if addition['l2'] == 1:
            pressed_btns.append(E_Joypad.L2)
        if addition['r1'] == 1:
            pressed_btns.append(E_Joypad.R1)
        if addition['r2'] == 1:
            pressed_btns.append(E_Joypad.R2)
        #
        if addition['l3'] == 1:
            pressed_btns.append(E_Joypad.LS)
        if addition['r3'] == 1:
            pressed_btns.append(E_Joypad.RS)

        button = data['button']
        if button['a'] == 1:
            pressed_btns.append(E_Joypad.A)
        if button['b'] == 1:
            pressed_btns.append(E_Joypad.B)
        if button['x'] == 1:
            pressed_btns.append(E_Joypad.X)
        if button['y'] == 1:
            pressed_btns.append(E_Joypad.Y)

        pressed_btns.sort()
        # 用于注册按键按下事件标识
        # code_button = BLUETOOTH.pressed_button_to_str(pressed_btns)

        return pressed_btns

    def get_joypad_coordinate(self):
        result = self.getBTJoypadStatus()

        if result is None or len(result) == 0:
            # 没有获取到事件
            return []

        data = json.loads(result)
        if data is None:
            logging.debug("warning-----no data in get_bt_joypad_status")
            return []

        sticks = []
        stick = data['stick']
        sticks.append(stick['l']['x'])
        sticks.append(stick['l']['y'])
        sticks.append(stick['r']['x'])
        sticks.append(stick['r']['y'])

        return sticks



import sys,os
sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import servo_pb2,servo_pb2_grpc
from base_client import GrpcClient

class ServoClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = servo_pb2_grpc.ServoServiceGrpcStub(channel=self.channel)

    def controlSingleClamp(self, status):
        # 控制夹手
        input_data = servo_pb2.ControlSingleClampRequest()
        input_data.status = status

        response = self.client.controlSingleClamp(input_data)
        return response

    def getClampStatus(self):
        # 获取夹手状态
        input_data = servo_pb2.GetClampStatusRequest()

        response = self.client.getClampStatus(input_data)
        return response.status


    def roboticArmRestory(self):
        # 机械臂复位
        input_data = servo_pb2.RoboticArmRestoryRequest()

        response = self.client.roboticArmRestory(input_data)
        return response

    def roboticArmMoveToTargetPostion(self, x, y, z, time):
        # 机械臂移动到指定的位置
        input_data = servo_pb2.RoboticArmMovePostionRequest()
        input_data.params.x = x
        input_data.params.y = y
        input_data.params.z = z
        input_data.params.time = int(time / 20)
        response = self.client.roboticArmMoveToTargetPostion(input_data)
        return response

    def roboticArmSetJointPosition(self, params, type=0):
        # 设置机械臂关节
        # params: [{"joint": 1, "position" :80, "time":1000}, ..]:
        input_data = servo_pb2.RoboticArmSetJointPositionRequest()
        for data in params:
            item = input_data.params.add()
            item.joint = data["joint"]
            item.position = data["position"]
            item.time = int(data["time"] / 20)
            item.type = type  # 0控制舵机角度1控制关节角度

        response = self.client.roboticArmSetJointPosition(input_data)
        return response

    def roboticArmGetJoints(self):
        # 获取机械臂关节
        input_data = servo_pb2.RoboticArmGetJointsRequest()

        response = self.client.roboticArmGetJoints(input_data)
        return response


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import servo_pb2 as servo__pb2


class ServoServiceGrpcStub(object):
    """定义服务,用在rpc传输中
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.setServoRotateBySpeed = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/setServoRotateBySpeed',
                request_serializer=servo__pb2.ServoRotateBySpeedRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoRotateResponse.FromString,
                )
        self.setServoRotateByAngle = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/setServoRotateByAngle',
                request_serializer=servo__pb2.ServoRotateByAngleRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoRotateResponse.FromString,
                )
        self.setServoRotateByPWM = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/setServoRotateByPWM',
                request_serializer=servo__pb2.ServoRotateByPWMRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoRotateResponse.FromString,
                )
        self.stopServoRotate = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/stopServoRotate',
                request_serializer=servo__pb2.StopServoRotateRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoCommonResponse.FromString,
                )
        self.getServoAngle = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/getServoAngle',
                request_serializer=servo__pb2.ServoGetAngleRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoGetAngleResponse.FromString,
                )
        self.isServoRotating = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/isServoRotating',
                request_serializer=servo__pb2.ServoGetRotatingRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoGetRotatingResponse.FromString,
                )
        self.clearServoFault = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/clearServoFault',
                request_serializer=servo__pb2.ServoFaultClearRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoCommonResponse.FromString,
                )
        self.getServoFault = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/getServoFault',
                request_serializer=servo__pb2.ServoFaultRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoFaultResponse.FromString,
                )
        self.controlSingleClamp = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/controlSingleClamp',
                request_serializer=servo__pb2.ControlSingleClampRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoCommonResponse.FromString,
                )
        self.getClampStatus = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/getClampStatus',
                request_serializer=servo__pb2.GetClampStatusRequest.SerializeToString,
                response_deserializer=servo__pb2.GetClampStatusResponse.FromString,
                )
        self.getMotionInfo = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/getMotionInfo',
                request_serializer=servo__pb2.GetMotionInfoRequest.SerializeToString,
                response_deserializer=servo__pb2.GetMotionInfoResponse.FromString,
                )
        self.roboticArmRestory = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/roboticArmRestory',
                request_serializer=servo__pb2.RoboticArmRestoryRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoCommonResponse.FromString,
                )
        self.roboticArmMoveToTargetPostion = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/roboticArmMoveToTargetPostion',
                request_serializer=servo__pb2.RoboticArmMovePostionRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoCommonResponse.FromString,
                )
        self.roboticArmSetJointPosition = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/roboticArmSetJointPosition',
                request_serializer=servo__pb2.RoboticArmSetJointPositionRequest.SerializeToString,
                response_deserializer=servo__pb2.ServoCommonResponse.FromString,
                )
        self.roboticArmGetJoints = channel.unary_unary(
                '/ServoPackage.ServoServiceGrpc/roboticArmGetJoints',
                request_serializer=servo__pb2.RoboticArmGetJointsRequest.SerializeToString,
                response_deserializer=servo__pb2.RoboticArmGetJointsResponse.FromString,
                )


class ServoServiceGrpcServicer(object):
    """定义服务,用在rpc传输中
    """

    def setServoRotateBySpeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setServoRotateByAngle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setServoRotateByPWM(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopServoRotate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getServoAngle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def isServoRotating(self, request, context):
        """获取转动状态，暂未实现
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def clearServoFault(self, request, context):
        """清除舵机异常
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getServoFault(self, request, context):
        """获取舵机异常信息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def controlSingleClamp(self, request, context):
        """控制夹手
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClampStatus(self, request, context):
        """获取夹手状态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMotionInfo(self, request, context):
        """获取运动信息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def roboticArmRestory(self, request, context):
        """机械臂复位
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def roboticArmMoveToTargetPostion(self, request, context):
        """机械臂移动到指定的位置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def roboticArmSetJointPosition(self, request, context):
        """设置机械臂关节
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def roboticArmGetJoints(self, request, context):
        """获取机械臂关节
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServoServiceGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'setServoRotateBySpeed': grpc.unary_unary_rpc_method_handler(
                    servicer.setServoRotateBySpeed,
                    request_deserializer=servo__pb2.ServoRotateBySpeedRequest.FromString,
                    response_serializer=servo__pb2.ServoRotateResponse.SerializeToString,
            ),
            'setServoRotateByAngle': grpc.unary_unary_rpc_method_handler(
                    servicer.setServoRotateByAngle,
                    request_deserializer=servo__pb2.ServoRotateByAngleRequest.FromString,
                    response_serializer=servo__pb2.ServoRotateResponse.SerializeToString,
            ),
            'setServoRotateByPWM': grpc.unary_unary_rpc_method_handler(
                    servicer.setServoRotateByPWM,
                    request_deserializer=servo__pb2.ServoRotateByPWMRequest.FromString,
                    response_serializer=servo__pb2.ServoRotateResponse.SerializeToString,
            ),
            'stopServoRotate': grpc.unary_unary_rpc_method_handler(
                    servicer.stopServoRotate,
                    request_deserializer=servo__pb2.StopServoRotateRequest.FromString,
                    response_serializer=servo__pb2.ServoCommonResponse.SerializeToString,
            ),
            'getServoAngle': grpc.unary_unary_rpc_method_handler(
                    servicer.getServoAngle,
                    request_deserializer=servo__pb2.ServoGetAngleRequest.FromString,
                    response_serializer=servo__pb2.ServoGetAngleResponse.SerializeToString,
            ),
            'isServoRotating': grpc.unary_unary_rpc_method_handler(
                    servicer.isServoRotating,
                    request_deserializer=servo__pb2.ServoGetRotatingRequest.FromString,
                    response_serializer=servo__pb2.ServoGetRotatingResponse.SerializeToString,
            ),
            'clearServoFault': grpc.unary_unary_rpc_method_handler(
                    servicer.clearServoFault,
                    request_deserializer=servo__pb2.ServoFaultClearRequest.FromString,
                    response_serializer=servo__pb2.ServoCommonResponse.SerializeToString,
            ),
            'getServoFault': grpc.unary_unary_rpc_method_handler(
                    servicer.getServoFault,
                    request_deserializer=servo__pb2.ServoFaultRequest.FromString,
                    response_serializer=servo__pb2.ServoFaultResponse.SerializeToString,
            ),
            'controlSingleClamp': grpc.unary_unary_rpc_method_handler(
                    servicer.controlSingleClamp,
                    request_deserializer=servo__pb2.ControlSingleClampRequest.FromString,
                    response_serializer=servo__pb2.ServoCommonResponse.SerializeToString,
            ),
            'getClampStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.getClampStatus,
                    request_deserializer=servo__pb2.GetClampStatusRequest.FromString,
                    response_serializer=servo__pb2.GetClampStatusResponse.SerializeToString,
            ),
            'getMotionInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getMotionInfo,
                    request_deserializer=servo__pb2.GetMotionInfoRequest.FromString,
                    response_serializer=servo__pb2.GetMotionInfoResponse.SerializeToString,
            ),
            'roboticArmRestory': grpc.unary_unary_rpc_method_handler(
                    servicer.roboticArmRestory,
                    request_deserializer=servo__pb2.RoboticArmRestoryRequest.FromString,
                    response_serializer=servo__pb2.ServoCommonResponse.SerializeToString,
            ),
            'roboticArmMoveToTargetPostion': grpc.unary_unary_rpc_method_handler(
                    servicer.roboticArmMoveToTargetPostion,
                    request_deserializer=servo__pb2.RoboticArmMovePostionRequest.FromString,
                    response_serializer=servo__pb2.ServoCommonResponse.SerializeToString,
            ),
            'roboticArmSetJointPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.roboticArmSetJointPosition,
                    request_deserializer=servo__pb2.RoboticArmSetJointPositionRequest.FromString,
                    response_serializer=servo__pb2.ServoCommonResponse.SerializeToString,
            ),
            'roboticArmGetJoints': grpc.unary_unary_rpc_method_handler(
                    servicer.roboticArmGetJoints,
                    request_deserializer=servo__pb2.RoboticArmGetJointsRequest.FromString,
                    response_serializer=servo__pb2.RoboticArmGetJointsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ServoPackage.ServoServiceGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServoServiceGrpc(object):
    """定义服务,用在rpc传输中
    """

    @staticmethod
    def setServoRotateBySpeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/setServoRotateBySpeed',
            servo__pb2.ServoRotateBySpeedRequest.SerializeToString,
            servo__pb2.ServoRotateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setServoRotateByAngle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/setServoRotateByAngle',
            servo__pb2.ServoRotateByAngleRequest.SerializeToString,
            servo__pb2.ServoRotateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setServoRotateByPWM(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/setServoRotateByPWM',
            servo__pb2.ServoRotateByPWMRequest.SerializeToString,
            servo__pb2.ServoRotateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopServoRotate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/stopServoRotate',
            servo__pb2.StopServoRotateRequest.SerializeToString,
            servo__pb2.ServoCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getServoAngle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/getServoAngle',
            servo__pb2.ServoGetAngleRequest.SerializeToString,
            servo__pb2.ServoGetAngleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def isServoRotating(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/isServoRotating',
            servo__pb2.ServoGetRotatingRequest.SerializeToString,
            servo__pb2.ServoGetRotatingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def clearServoFault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/clearServoFault',
            servo__pb2.ServoFaultClearRequest.SerializeToString,
            servo__pb2.ServoCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getServoFault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/getServoFault',
            servo__pb2.ServoFaultRequest.SerializeToString,
            servo__pb2.ServoFaultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def controlSingleClamp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/controlSingleClamp',
            servo__pb2.ControlSingleClampRequest.SerializeToString,
            servo__pb2.ServoCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClampStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/getClampStatus',
            servo__pb2.GetClampStatusRequest.SerializeToString,
            servo__pb2.GetClampStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMotionInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/getMotionInfo',
            servo__pb2.GetMotionInfoRequest.SerializeToString,
            servo__pb2.GetMotionInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def roboticArmRestory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/roboticArmRestory',
            servo__pb2.RoboticArmRestoryRequest.SerializeToString,
            servo__pb2.ServoCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def roboticArmMoveToTargetPostion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/roboticArmMoveToTargetPostion',
            servo__pb2.RoboticArmMovePostionRequest.SerializeToString,
            servo__pb2.ServoCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def roboticArmSetJointPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/roboticArmSetJointPosition',
            servo__pb2.RoboticArmSetJointPositionRequest.SerializeToString,
            servo__pb2.ServoCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def roboticArmGetJoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ServoPackage.ServoServiceGrpc/roboticArmGetJoints',
            servo__pb2.RoboticArmGetJointsRequest.SerializeToString,
            servo__pb2.RoboticArmGetJointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x0cModelPackage\"\x88\x01\n\x12ModelControlParams\x12\x14\n\x0clinear_speed\x18\x01 \x01(\x05\x12\x11\n\tdirection\x18\x02 \x01(\x05\x12\x14\n\x0crotate_speed\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x05\x12\x0f\n\x07mileage\x18\x05 \x01(\x05\x12\x14\n\x0ctarget_angle\x18\x06 \x01(\x05\"j\n\x13ModelControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32 .ModelPackage.ModelControlParams\x12\x13\n\x0b\x63lient_type\x18\x03 \x01(\x05\">\n\x13ModelCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"\\\n\x12MotorControlParams\x12\x10\n\x08lf_joint\x18\x01 \x01(\x05\x12\x10\n\x08rf_joint\x18\x02 \x01(\x05\x12\x10\n\x08lb_joint\x18\x03 \x01(\x05\x12\x10\n\x08rb_joint\x18\x04 \x01(\x05\"U\n\x13MotorControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32 .ModelPackage.MotorControlParams\"G\n\x10XYZControlParams\x12\x10\n\x08linear_x\x18\x01 \x01(\x05\x12\x10\n\x08linear_y\x18\x02 \x01(\x05\x12\x0f\n\x07\x61ngle_z\x18\x03 \x01(\x05\"Q\n\x11XYZControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12.\n\x06params\x18\x02 \x01(\x0b\x32\x1e.ModelPackage.XYZControlParams\"\"\n\x12MecanumStopRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"A\n\x1a\x42\x61lanceKeepBalancingParams\x12\r\n\x05start\x18\x01 \x01(\x08\x12\x14\n\x0ckeep_balance\x18\x02 \x01(\x08\"e\n\x1b\x42\x61lanceKeepBalancingRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.ModelPackage.BalanceKeepBalancingParams\"J\n\x19TransformArmsControlParam\x12\r\n\x05joint\x18\x01 \x01(\x05\x12\x10\n\x08position\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\x05\"d\n\x1bTransformArmsControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.ModelPackage.TransformArmsControlParam\")\n\x17TransformSetHeightParam\x12\x0e\n\x06height\x18\x01 \x01(\x05\"`\n\x19TransformSetHeightRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32%.ModelPackage.TransformSetHeightParam\")\n\x17\x45nableAdaptivePoseParam\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x05\"`\n\x19\x45nableAdaptivePoseRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32%.ModelPackage.EnableAdaptivePoseParam\"5\n TransformSetHeightIncrementParam\x12\x11\n\tincrement\x18\x01 \x01(\x05\"\x87\x01\n\"TransformSetHeightIncrementRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12>\n\x06params\x18\x02 \x01(\x0b\x32..ModelPackage.TransformSetHeightIncrementParam\x12\x13\n\x0b\x63lient_type\x18\x03 \x01(\x05\")\n\x19WheelleggedRestoryRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"7\n\x19WheelleggedSetHeightParam\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04gear\x18\x02 \x01(\x05\"d\n\x1bWheelleggedSetHeightRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.ModelPackage.WheelleggedSetHeightParam\"G\n\x1cWheelleggedSetLeanAngleParam\x12\x0c\n\x04pose\x18\x01 \x01(\x05\x12\x19\n\x11inclination_angle\x18\x02 \x01(\x02\"j\n\x1eWheelleggedSetLeanAngleRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32*.ModelPackage.WheelleggedSetLeanAngleParam\"\x86\x01\n\x15SetAccelerationParams\x12\x10\n\x08linear_x\x18\x01 \x01(\x01\x12\x10\n\x08linear_y\x18\x02 \x01(\x01\x12\x10\n\x08linear_z\x18\x03 \x01(\x01\x12\x11\n\tangular_x\x18\x04 \x01(\x01\x12\x11\n\tangular_y\x18\x05 \x01(\x01\x12\x11\n\tangular_z\x18\x06 \x01(\x01\"[\n\x16SetAccelerationRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32#.ModelPackage.SetAccelerationParams\"(\n\x18ResetAccelerationRequest\x12\x0c\n\x04type\x18\x01 \x01(\t2\x8a\x0b\n\x10ModelServiceGrpc\x12\\\n\x12modelCommonControl\x12!.ModelPackage.ModelControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12]\n\x13mecanumMotorControl\x12!.ModelPackage.MotorControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12Y\n\x11mecanumXYZControl\x12\x1f.ModelPackage.XYZControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12T\n\x0bmecanumStop\x12 .ModelPackage.MecanumStopRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x66\n\x14\x62\x61lanceKeepBalancing\x12).ModelPackage.BalanceKeepBalancingRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x66\n\x14transformArmsControl\x12).ModelPackage.TransformArmsControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x62\n\x12transformSetHeight\x12\'.ModelPackage.TransformSetHeightRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x62\n\x12\x65nableAdaptivePose\x12\'.ModelPackage.EnableAdaptivePoseRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12v\n\x1dtransformSetHeightByIncrement\x12\x30.ModelPackage.TransformSetHeightIncrementRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x62\n\x12wheelleggedRestory\x12\'.ModelPackage.WheelleggedRestoryRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x66\n\x14wheelleggedSetHeight\x12).ModelPackage.WheelleggedSetHeightRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12l\n\x17wheelleggedSetLeanAngle\x12,.ModelPackage.WheelleggedSetLeanAngleRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\\\n\x0fsetAcceleration\x12$.ModelPackage.SetAccelerationRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12`\n\x11resetAcceleration\x12&.ModelPackage.ResetAccelerationRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MODELCONTROLPARAMS._serialized_start=30
  _MODELCONTROLPARAMS._serialized_end=166
  _MODELCONTROLREQUEST._serialized_start=168
  _MODELCONTROLREQUEST._serialized_end=274
  _MODELCOMMONRESPONSE._serialized_start=276
  _MODELCOMMONRESPONSE._serialized_end=338
  _MOTORCONTROLPARAMS._serialized_start=340
  _MOTORCONTROLPARAMS._serialized_end=432
  _MOTORCONTROLREQUEST._serialized_start=434
  _MOTORCONTROLREQUEST._serialized_end=519
  _XYZCONTROLPARAMS._serialized_start=521
  _XYZCONTROLPARAMS._serialized_end=592
  _XYZCONTROLREQUEST._serialized_start=594
  _XYZCONTROLREQUEST._serialized_end=675
  _MECANUMSTOPREQUEST._serialized_start=677
  _MECANUMSTOPREQUEST._serialized_end=711
  _BALANCEKEEPBALANCINGPARAMS._serialized_start=713
  _BALANCEKEEPBALANCINGPARAMS._serialized_end=778
  _BALANCEKEEPBALANCINGREQUEST._serialized_start=780
  _BALANCEKEEPBALANCINGREQUEST._serialized_end=881
  _TRANSFORMARMSCONTROLPARAM._serialized_start=883
  _TRANSFORMARMSCONTROLPARAM._serialized_end=957
  _TRANSFORMARMSCONTROLREQUEST._serialized_start=959
  _TRANSFORMARMSCONTROLREQUEST._serialized_end=1059
  _TRANSFORMSETHEIGHTPARAM._serialized_start=1061
  _TRANSFORMSETHEIGHTPARAM._serialized_end=1102
  _TRANSFORMSETHEIGHTREQUEST._serialized_start=1104
  _TRANSFORMSETHEIGHTREQUEST._serialized_end=1200
  _ENABLEADAPTIVEPOSEPARAM._serialized_start=1202
  _ENABLEADAPTIVEPOSEPARAM._serialized_end=1243
  _ENABLEADAPTIVEPOSEREQUEST._serialized_start=1245
  _ENABLEADAPTIVEPOSEREQUEST._serialized_end=1341
  _TRANSFORMSETHEIGHTINCREMENTPARAM._serialized_start=1343
  _TRANSFORMSETHEIGHTINCREMENTPARAM._serialized_end=1396
  _TRANSFORMSETHEIGHTINCREMENTREQUEST._serialized_start=1399
  _TRANSFORMSETHEIGHTINCREMENTREQUEST._serialized_end=1534
  _WHEELLEGGEDRESTORYREQUEST._serialized_start=1536
  _WHEELLEGGEDRESTORYREQUEST._serialized_end=1577
  _WHEELLEGGEDSETHEIGHTPARAM._serialized_start=1579
  _WHEELLEGGEDSETHEIGHTPARAM._serialized_end=1634
  _WHEELLEGGEDSETHEIGHTREQUEST._serialized_start=1636
  _WHEELLEGGEDSETHEIGHTREQUEST._serialized_end=1736
  _WHEELLEGGEDSETLEANANGLEPARAM._serialized_start=1738
  _WHEELLEGGEDSETLEANANGLEPARAM._serialized_end=1809
  _WHEELLEGGEDSETLEANANGLEREQUEST._serialized_start=1811
  _WHEELLEGGEDSETLEANANGLEREQUEST._serialized_end=1917
  _SETACCELERATIONPARAMS._serialized_start=1920
  _SETACCELERATIONPARAMS._serialized_end=2054
  _SETACCELERATIONREQUEST._serialized_start=2056
  _SETACCELERATIONREQUEST._serialized_end=2147
  _RESETACCELERATIONREQUEST._serialized_start=2149
  _RESETACCELERATIONREQUEST._serialized_end=2189
  _MODELSERVICEGRPC._serialized_start=2192
  _MODELSERVICEGRPC._serialized_end=3610
# @@protoc_insertion_point(module_scope)



class E_Model:
    class Direction:
        forward = 0  # 前进
        backward = 1  # 后退
        turn_left = 2  # 左转
        turn_right = 3  # 右转

    class Unit:
        second = 0  # 秒
        mileage = 1  # 厘米
        angle = 2  # 度

    class ArmJoint:
        left_forward = 1
        left_backward = 2
        right_backward = 3
        right_forward = 4

    class ArmControl:
        RELEASE = 0
        CLOSE = 1

    class Adaption:
        OFF = 0
        ON = 1

    class Mechanical:
        joint1 = 1
        joint2 = 2
        joint3 = 3

    class WheelLegHeight:
        HIGH = 1
        MEDIUM = 2
        LOW = 3

class E_Device:
    class Color:
        black = 0  # 黑色
        white = 1  # 白色
        purple = 2  # 紫色
        red = 3  # 红色
        orange = 4  # 橙色
        yellow = 5  # 黄色
        green = 6  # 绿色
        cyan = 7  # 青色
        blue = 8  # 蓝色
        ColorList = {
            black: "FF000000",
            white: "FFFFFFFF",
            purple: "FFFF00FF",
            red: "FFFF0000",
            orange: "FFFFA500",
            yellow: "FFFFFF00",
            green: "FF00FF00",
            cyan: "FF00FFFF",
            blue: "FF0000FF",
        }

    class Light:
        class ID:
            TOP = 0
            LEFT = 1
            RIGHT = 2
            DOWN = 3

        class Effect:
            TURN_ON = 0  # 常亮
            TURN_OFF = 1  # 关闭
            BREATHING = 2  # 呼吸
            FLASHING = 3  # 闪烁

class E_Vision:
    class Traffic:
        green_light = 0 # 绿灯
        horn = 1 # 鸣笛
        left = 2 # 左转
        right = 3 # 右转
        zebra_crossing = 4 # 斑马线
        red_light = 5 # 红灯
        children = 6 # 注意儿童
        stop = 7 # 禁止长时间停车
        tunnel = 8 # 进入隧道
        yellow_light = 9 # 黄灯

        TrafficSigns = {
            green_light : '绿灯',
            horn: '鸣笛',
            left: '左转',
            right: '右转',
            zebra_crossing: '斑马线',
            red_light: '红灯',
            children: '注意儿童',
            stop: '禁止长时间停车',
            tunnel: '进入隧道',
            yellow_light: '黄灯',
        }
    class LPD:
        # "蓝牌", "绿牌", "黄牌", "黑牌", "黄绿牌", "不确定"
        blue = 0 # 蓝牌
        green = 1 # 绿牌
        yellow = 2 # 黄牌
        black = 3 # 黑牌
        yellow_green = 4 # 黄绿牌
        unknown = 5 # 不确定

    class Pose:
        nose = 0  # 鼻子
        neck = 1  # 脖子
        rightShoulder = 2  # 右肩
        rightElbow = 3  # 右肘
        rightWrist = 4  # 右手
        leftShoulder = 5  # 左肩
        leftElbow = 6  # 左肘
        leftWrist = 7  # 左手
        rightHip = 8  # 右胯
        rightKnee = 9  # 右膝
        rightAnkle = 10  # 右脚
        leftHip = 11  # 左胯
        leftKnee = 12  # 左膝
        leftAnkle = 13  # 左脚
        rightEye = 14  # 右眼
        leftEye = 15  # 左眼
        rightEar = 16  # 右耳
        leftEar = 17  # 左耳

        TotalPoseIndexes = [rightEar, rightEye, nose, leftEye, leftEar,
                            rightWrist, rightElbow, rightShoulder, leftShoulder, leftElbow, leftWrist,
                            rightHip, leftHip, rightKnee, leftKnee, rightAnkle, leftAnkle]

    class Intersection:
        crossroad = 0  # 十字路口
        ycross = 1  # y字路口
        straight = 2  # 一条直线
        junction = 3  # 路口 - 双轨判断
        noline = 10  # 无线

    class LineColor:
        # 0.1.2.3.4 对应黑白蓝绿红
        black = 0  # 黑色
        white = 1  # 白色
        blue = 2  # 蓝色
        green = 3  # 绿色
        red = 4  # 红色

    class LineType:
        single = 0  # 单轨
        double = 1  # 双轨

class E_Audio:
    class Volume:
        MINIMUM = 1  # 最小 20%
        LOW = 2  # 小 40%
        MEDIUM = 3  # 中 60%
        HIGH = 4  # 大 80%
        MAXIMUM = 5  # 最大 100%

    class Type:
        UPLOAD = 0 # 0 上传的音频
        RECORD = 1  # 1 表示录音
        DEFAULT = 2  # 2 表示内部音效

    class Direction:
        FRONT = 1
        BACK = 2
        LEFT = 3
        RIGHT = 4

    class Timbre:
        Female = 0  # 女声
        Male = 1  # 男声

    class DirectionControl:
        ON = 1  # 开启声源定位
        OFF = 0  # 关闭声源定位

    class Beat:
        EIGHTH = 0
        QUARTER = 1
        HALF = 2
        ONE = 3
        DOUBLE = 4
        BEATS = {
            EIGHTH : '1-8',
            QUARTER : '1-4',
            HALF : '1-2',
            ONE : '1',
            DOUBLE : '2',
        }

class E_Joypad:

    X = 'X' # X
    Y = 'Y' # Y
    A = 'A' # A
    B = 'B' # B
    L1 = 'L1' # L1
    L2 = 'L2' # L2
    R1 = 'R1' # R1
    R2 = 'R2' # R2
    LS = 'LS' # LS 左滚轮
    RS = 'RS' # RS 右滚轮
    U = 'U' # 方向 - 上
    D = 'D' # 方向 - 下
    L = 'L' # 方向 - 左
    R = 'R' # 方向 - 右




# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import device_pb2 as device__pb2


class DeviceServiceGrpcStub(object):
    """包括设备列表、显示屏、灯条等服务
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getDeviceList = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/getDeviceList',
                request_serializer=device__pb2.DeviceListRequest.SerializeToString,
                response_deserializer=device__pb2.DeviceListResponse.FromString,
                )
        self.startDeviceListChangeListener = channel.unary_stream(
                '/DevicePackage.DeviceServiceGrpc/startDeviceListChangeListener',
                request_serializer=device__pb2.DeviceListRequest.SerializeToString,
                response_deserializer=device__pb2.DeviceListResponse.FromString,
                )
        self.stopDeviceListChangeListener = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/stopDeviceListChangeListener',
                request_serializer=device__pb2.DeviceListRequest.SerializeToString,
                response_deserializer=device__pb2.DeviceCommonResponse.FromString,
                )
        self.setDisplayUI = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/setDisplayUI',
                request_serializer=device__pb2.DisplayUIRequest.SerializeToString,
                response_deserializer=device__pb2.DisplayUIResponse.FromString,
                )
        self.getDisplayPictureList = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/getDisplayPictureList',
                request_serializer=device__pb2.DisplayPictureListRequest.SerializeToString,
                response_deserializer=device__pb2.DisplayPictureListResponse.FromString,
                )
        self.deleteDisplayPicture = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/deleteDisplayPicture',
                request_serializer=device__pb2.DeleteDisplayPictureRequest.SerializeToString,
                response_deserializer=device__pb2.DeviceCommonResponse.FromString,
                )
        self.stopDisplayUI = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/stopDisplayUI',
                request_serializer=device__pb2.DeviceCommonRequest.SerializeToString,
                response_deserializer=device__pb2.DeviceCommonResponse.FromString,
                )
        self.setBrightness = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/setBrightness',
                request_serializer=device__pb2.SetBrightnessRequest.SerializeToString,
                response_deserializer=device__pb2.BrightnessResponse.FromString,
                )
        self.getBrightness = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/getBrightness',
                request_serializer=device__pb2.GetBrightnessRequest.SerializeToString,
                response_deserializer=device__pb2.BrightnessResponse.FromString,
                )
        self.getMacAddress = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/getMacAddress',
                request_serializer=device__pb2.MacAddressRequest.SerializeToString,
                response_deserializer=device__pb2.MacAddressResponse.FromString,
                )
        self.setVolume = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/setVolume',
                request_serializer=device__pb2.SetVolumeRequest.SerializeToString,
                response_deserializer=device__pb2.VolumeResponse.FromString,
                )
        self.getVolume = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/getVolume',
                request_serializer=device__pb2.GetVolumeRequest.SerializeToString,
                response_deserializer=device__pb2.VolumeResponse.FromString,
                )
        self.muteVolume = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/muteVolume',
                request_serializer=device__pb2.MuteVolumeRequest.SerializeToString,
                response_deserializer=device__pb2.VolumeResponse.FromString,
                )
        self.selectModel = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/selectModel',
                request_serializer=device__pb2.SelectModelRequest.SerializeToString,
                response_deserializer=device__pb2.SelectModelResponse.FromString,
                )
        self.getDeviceModel = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/getDeviceModel',
                request_serializer=device__pb2.DeviceModelRequest.SerializeToString,
                response_deserializer=device__pb2.DeviceModelResponse.FromString,
                )
        self.getDeviceSoftwareVersion = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/getDeviceSoftwareVersion',
                request_serializer=device__pb2.DeviceCommonRequest.SerializeToString,
                response_deserializer=device__pb2.DeviceVersionResponse.FromString,
                )
        self.showLightEffect = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/showLightEffect',
                request_serializer=device__pb2.LightEffectRequest.SerializeToString,
                response_deserializer=device__pb2.LightResponse.FromString,
                )
        self.showLightColor = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/showLightColor',
                request_serializer=device__pb2.LightColorRequest.SerializeToString,
                response_deserializer=device__pb2.LightResponse.FromString,
                )
        self.turnOffLight = channel.unary_unary(
                '/DevicePackage.DeviceServiceGrpc/turnOffLight',
                request_serializer=device__pb2.TurnOffLightRequest.SerializeToString,
                response_deserializer=device__pb2.LightResponse.FromString,
                )


class DeviceServiceGrpcServicer(object):
    """包括设备列表、显示屏、灯条等服务
    """

    def getDeviceList(self, request, context):
        """定义设备列表服务
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startDeviceListChangeListener(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopDeviceListChangeListener(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setDisplayUI(self, request, context):
        """定义显示屏服务
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDisplayPictureList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteDisplayPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopDisplayUI(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setBrightness(self, request, context):
        """设置屏幕背光亮度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getBrightness(self, request, context):
        """获取背光亮度值
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMacAddress(self, request, context):
        """获取wlan0 Mac地址    
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setVolume(self, request, context):
        """设置音量
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getVolume(self, request, context):
        """获取音量
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def muteVolume(self, request, context):
        """静音
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def selectModel(self, request, context):
        """选择模型
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDeviceModel(self, request, context):
        """获取模型
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDeviceSoftwareVersion(self, request, context):
        """获取软件版本号
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def showLightEffect(self, request, context):
        """灯效
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def showLightColor(self, request, context):
        """灯光
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def turnOffLight(self, request, context):
        """关闭灯光
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeviceServiceGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getDeviceList': grpc.unary_unary_rpc_method_handler(
                    servicer.getDeviceList,
                    request_deserializer=device__pb2.DeviceListRequest.FromString,
                    response_serializer=device__pb2.DeviceListResponse.SerializeToString,
            ),
            'startDeviceListChangeListener': grpc.unary_stream_rpc_method_handler(
                    servicer.startDeviceListChangeListener,
                    request_deserializer=device__pb2.DeviceListRequest.FromString,
                    response_serializer=device__pb2.DeviceListResponse.SerializeToString,
            ),
            'stopDeviceListChangeListener': grpc.unary_unary_rpc_method_handler(
                    servicer.stopDeviceListChangeListener,
                    request_deserializer=device__pb2.DeviceListRequest.FromString,
                    response_serializer=device__pb2.DeviceCommonResponse.SerializeToString,
            ),
            'setDisplayUI': grpc.unary_unary_rpc_method_handler(
                    servicer.setDisplayUI,
                    request_deserializer=device__pb2.DisplayUIRequest.FromString,
                    response_serializer=device__pb2.DisplayUIResponse.SerializeToString,
            ),
            'getDisplayPictureList': grpc.unary_unary_rpc_method_handler(
                    servicer.getDisplayPictureList,
                    request_deserializer=device__pb2.DisplayPictureListRequest.FromString,
                    response_serializer=device__pb2.DisplayPictureListResponse.SerializeToString,
            ),
            'deleteDisplayPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteDisplayPicture,
                    request_deserializer=device__pb2.DeleteDisplayPictureRequest.FromString,
                    response_serializer=device__pb2.DeviceCommonResponse.SerializeToString,
            ),
            'stopDisplayUI': grpc.unary_unary_rpc_method_handler(
                    servicer.stopDisplayUI,
                    request_deserializer=device__pb2.DeviceCommonRequest.FromString,
                    response_serializer=device__pb2.DeviceCommonResponse.SerializeToString,
            ),
            'setBrightness': grpc.unary_unary_rpc_method_handler(
                    servicer.setBrightness,
                    request_deserializer=device__pb2.SetBrightnessRequest.FromString,
                    response_serializer=device__pb2.BrightnessResponse.SerializeToString,
            ),
            'getBrightness': grpc.unary_unary_rpc_method_handler(
                    servicer.getBrightness,
                    request_deserializer=device__pb2.GetBrightnessRequest.FromString,
                    response_serializer=device__pb2.BrightnessResponse.SerializeToString,
            ),
            'getMacAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.getMacAddress,
                    request_deserializer=device__pb2.MacAddressRequest.FromString,
                    response_serializer=device__pb2.MacAddressResponse.SerializeToString,
            ),
            'setVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.setVolume,
                    request_deserializer=device__pb2.SetVolumeRequest.FromString,
                    response_serializer=device__pb2.VolumeResponse.SerializeToString,
            ),
            'getVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.getVolume,
                    request_deserializer=device__pb2.GetVolumeRequest.FromString,
                    response_serializer=device__pb2.VolumeResponse.SerializeToString,
            ),
            'muteVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.muteVolume,
                    request_deserializer=device__pb2.MuteVolumeRequest.FromString,
                    response_serializer=device__pb2.VolumeResponse.SerializeToString,
            ),
            'selectModel': grpc.unary_unary_rpc_method_handler(
                    servicer.selectModel,
                    request_deserializer=device__pb2.SelectModelRequest.FromString,
                    response_serializer=device__pb2.SelectModelResponse.SerializeToString,
            ),
            'getDeviceModel': grpc.unary_unary_rpc_method_handler(
                    servicer.getDeviceModel,
                    request_deserializer=device__pb2.DeviceModelRequest.FromString,
                    response_serializer=device__pb2.DeviceModelResponse.SerializeToString,
            ),
            'getDeviceSoftwareVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.getDeviceSoftwareVersion,
                    request_deserializer=device__pb2.DeviceCommonRequest.FromString,
                    response_serializer=device__pb2.DeviceVersionResponse.SerializeToString,
            ),
            'showLightEffect': grpc.unary_unary_rpc_method_handler(
                    servicer.showLightEffect,
                    request_deserializer=device__pb2.LightEffectRequest.FromString,
                    response_serializer=device__pb2.LightResponse.SerializeToString,
            ),
            'showLightColor': grpc.unary_unary_rpc_method_handler(
                    servicer.showLightColor,
                    request_deserializer=device__pb2.LightColorRequest.FromString,
                    response_serializer=device__pb2.LightResponse.SerializeToString,
            ),
            'turnOffLight': grpc.unary_unary_rpc_method_handler(
                    servicer.turnOffLight,
                    request_deserializer=device__pb2.TurnOffLightRequest.FromString,
                    response_serializer=device__pb2.LightResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DevicePackage.DeviceServiceGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeviceServiceGrpc(object):
    """包括设备列表、显示屏、灯条等服务
    """

    @staticmethod
    def getDeviceList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/getDeviceList',
            device__pb2.DeviceListRequest.SerializeToString,
            device__pb2.DeviceListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startDeviceListChangeListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DevicePackage.DeviceServiceGrpc/startDeviceListChangeListener',
            device__pb2.DeviceListRequest.SerializeToString,
            device__pb2.DeviceListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopDeviceListChangeListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/stopDeviceListChangeListener',
            device__pb2.DeviceListRequest.SerializeToString,
            device__pb2.DeviceCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setDisplayUI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/setDisplayUI',
            device__pb2.DisplayUIRequest.SerializeToString,
            device__pb2.DisplayUIResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDisplayPictureList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/getDisplayPictureList',
            device__pb2.DisplayPictureListRequest.SerializeToString,
            device__pb2.DisplayPictureListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteDisplayPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/deleteDisplayPicture',
            device__pb2.DeleteDisplayPictureRequest.SerializeToString,
            device__pb2.DeviceCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopDisplayUI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/stopDisplayUI',
            device__pb2.DeviceCommonRequest.SerializeToString,
            device__pb2.DeviceCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setBrightness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/setBrightness',
            device__pb2.SetBrightnessRequest.SerializeToString,
            device__pb2.BrightnessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getBrightness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/getBrightness',
            device__pb2.GetBrightnessRequest.SerializeToString,
            device__pb2.BrightnessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMacAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/getMacAddress',
            device__pb2.MacAddressRequest.SerializeToString,
            device__pb2.MacAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/setVolume',
            device__pb2.SetVolumeRequest.SerializeToString,
            device__pb2.VolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/getVolume',
            device__pb2.GetVolumeRequest.SerializeToString,
            device__pb2.VolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def muteVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/muteVolume',
            device__pb2.MuteVolumeRequest.SerializeToString,
            device__pb2.VolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def selectModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/selectModel',
            device__pb2.SelectModelRequest.SerializeToString,
            device__pb2.SelectModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDeviceModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/getDeviceModel',
            device__pb2.DeviceModelRequest.SerializeToString,
            device__pb2.DeviceModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDeviceSoftwareVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/getDeviceSoftwareVersion',
            device__pb2.DeviceCommonRequest.SerializeToString,
            device__pb2.DeviceVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def showLightEffect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/showLightEffect',
            device__pb2.LightEffectRequest.SerializeToString,
            device__pb2.LightResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def showLightColor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/showLightColor',
            device__pb2.LightColorRequest.SerializeToString,
            device__pb2.LightResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def turnOffLight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DevicePackage.DeviceServiceGrpc/turnOffLight',
            device__pb2.TurnOffLightRequest.SerializeToString,
            device__pb2.LightResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import vision_pb2 as vision__pb2


class AIVisionServiceGrpcStub(object):
    """定义服务,用在rpc传输中
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.trainAndSave = channel.unary_stream(
                '/AIVisionPackage.AIVisionServiceGrpc/trainAndSave',
                request_serializer=vision__pb2.TrainAndSaveRequest.SerializeToString,
                response_deserializer=vision__pb2.TrainAndSaveResponse.FromString,
                )
        self.loadModel = channel.unary_unary(
                '/AIVisionPackage.AIVisionServiceGrpc/loadModel',
                request_serializer=vision__pb2.LoadModelRequest.SerializeToString,
                response_deserializer=vision__pb2.LoadModelResponse.FromString,
                )
        self.setModelPara = channel.unary_unary(
                '/AIVisionPackage.AIVisionServiceGrpc/setModelPara',
                request_serializer=vision__pb2.SetModelParaRequest.SerializeToString,
                response_deserializer=vision__pb2.SetModelParaResponse.FromString,
                )
        self.doModelInference = channel.unary_unary(
                '/AIVisionPackage.AIVisionServiceGrpc/doModelInference',
                request_serializer=vision__pb2.InferenceRequest.SerializeToString,
                response_deserializer=vision__pb2.InferenceResponse.FromString,
                )
        self.releaseModel = channel.unary_unary(
                '/AIVisionPackage.AIVisionServiceGrpc/releaseModel',
                request_serializer=vision__pb2.ReleaseModelRequest.SerializeToString,
                response_deserializer=vision__pb2.ReleaseModelResponse.FromString,
                )
        self.startAutoInference = channel.unary_stream(
                '/AIVisionPackage.AIVisionServiceGrpc/startAutoInference',
                request_serializer=vision__pb2.AutoInferenceRequest.SerializeToString,
                response_deserializer=vision__pb2.InferenceResponse.FromString,
                )
        self.stopAutoInference = channel.unary_unary(
                '/AIVisionPackage.AIVisionServiceGrpc/stopAutoInference',
                request_serializer=vision__pb2.EmptyRequest.SerializeToString,
                response_deserializer=vision__pb2.CommonResponse.FromString,
                )
        self.startPushInferenceResult = channel.unary_stream(
                '/AIVisionPackage.AIVisionServiceGrpc/startPushInferenceResult',
                request_serializer=vision__pb2.EmptyRequest.SerializeToString,
                response_deserializer=vision__pb2.InferenceResponse.FromString,
                )
        self.stopPushInferenceResult = channel.unary_unary(
                '/AIVisionPackage.AIVisionServiceGrpc/stopPushInferenceResult',
                request_serializer=vision__pb2.EmptyRequest.SerializeToString,
                response_deserializer=vision__pb2.CommonResponse.FromString,
                )
        self.getCameraNumber = channel.unary_unary(
                '/AIVisionPackage.AIVisionServiceGrpc/getCameraNumber',
                request_serializer=vision__pb2.EmptyRequest.SerializeToString,
                response_deserializer=vision__pb2.CameraNumberResponse.FromString,
                )


class AIVisionServiceGrpcServicer(object):
    """定义服务,用在rpc传输中
    """

    def trainAndSave(self, request, context):
        """训练模型
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def loadModel(self, request, context):
        """加载模型
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setModelPara(self, request, context):
        """设置参数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def doModelInference(self, request, context):
        """推理
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def releaseModel(self, request, context):
        """释放部分模型,当列表为空时表示释放所有模型
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startAutoInference(self, request, context):
        """开始自动推理
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopAutoInference(self, request, context):
        """停止自动推理
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startPushInferenceResult(self, request, context):
        """使能推理结果上送
        使能之后，每次推理（自动推理，单次推理）后，将结果通过消息上送
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopPushInferenceResult(self, request, context):
        """去使能推理结果上送
        去使能之后，推理结果不上送
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getCameraNumber(self, request, context):
        """摄像头个数查询
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AIVisionServiceGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'trainAndSave': grpc.unary_stream_rpc_method_handler(
                    servicer.trainAndSave,
                    request_deserializer=vision__pb2.TrainAndSaveRequest.FromString,
                    response_serializer=vision__pb2.TrainAndSaveResponse.SerializeToString,
            ),
            'loadModel': grpc.unary_unary_rpc_method_handler(
                    servicer.loadModel,
                    request_deserializer=vision__pb2.LoadModelRequest.FromString,
                    response_serializer=vision__pb2.LoadModelResponse.SerializeToString,
            ),
            'setModelPara': grpc.unary_unary_rpc_method_handler(
                    servicer.setModelPara,
                    request_deserializer=vision__pb2.SetModelParaRequest.FromString,
                    response_serializer=vision__pb2.SetModelParaResponse.SerializeToString,
            ),
            'doModelInference': grpc.unary_unary_rpc_method_handler(
                    servicer.doModelInference,
                    request_deserializer=vision__pb2.InferenceRequest.FromString,
                    response_serializer=vision__pb2.InferenceResponse.SerializeToString,
            ),
            'releaseModel': grpc.unary_unary_rpc_method_handler(
                    servicer.releaseModel,
                    request_deserializer=vision__pb2.ReleaseModelRequest.FromString,
                    response_serializer=vision__pb2.ReleaseModelResponse.SerializeToString,
            ),
            'startAutoInference': grpc.unary_stream_rpc_method_handler(
                    servicer.startAutoInference,
                    request_deserializer=vision__pb2.AutoInferenceRequest.FromString,
                    response_serializer=vision__pb2.InferenceResponse.SerializeToString,
            ),
            'stopAutoInference': grpc.unary_unary_rpc_method_handler(
                    servicer.stopAutoInference,
                    request_deserializer=vision__pb2.EmptyRequest.FromString,
                    response_serializer=vision__pb2.CommonResponse.SerializeToString,
            ),
            'startPushInferenceResult': grpc.unary_stream_rpc_method_handler(
                    servicer.startPushInferenceResult,
                    request_deserializer=vision__pb2.EmptyRequest.FromString,
                    response_serializer=vision__pb2.InferenceResponse.SerializeToString,
            ),
            'stopPushInferenceResult': grpc.unary_unary_rpc_method_handler(
                    servicer.stopPushInferenceResult,
                    request_deserializer=vision__pb2.EmptyRequest.FromString,
                    response_serializer=vision__pb2.CommonResponse.SerializeToString,
            ),
            'getCameraNumber': grpc.unary_unary_rpc_method_handler(
                    servicer.getCameraNumber,
                    request_deserializer=vision__pb2.EmptyRequest.FromString,
                    response_serializer=vision__pb2.CameraNumberResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'AIVisionPackage.AIVisionServiceGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AIVisionServiceGrpc(object):
    """定义服务,用在rpc传输中
    """

    @staticmethod
    def trainAndSave(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/AIVisionPackage.AIVisionServiceGrpc/trainAndSave',
            vision__pb2.TrainAndSaveRequest.SerializeToString,
            vision__pb2.TrainAndSaveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def loadModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AIVisionPackage.AIVisionServiceGrpc/loadModel',
            vision__pb2.LoadModelRequest.SerializeToString,
            vision__pb2.LoadModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setModelPara(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AIVisionPackage.AIVisionServiceGrpc/setModelPara',
            vision__pb2.SetModelParaRequest.SerializeToString,
            vision__pb2.SetModelParaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def doModelInference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AIVisionPackage.AIVisionServiceGrpc/doModelInference',
            vision__pb2.InferenceRequest.SerializeToString,
            vision__pb2.InferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def releaseModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AIVisionPackage.AIVisionServiceGrpc/releaseModel',
            vision__pb2.ReleaseModelRequest.SerializeToString,
            vision__pb2.ReleaseModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startAutoInference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/AIVisionPackage.AIVisionServiceGrpc/startAutoInference',
            vision__pb2.AutoInferenceRequest.SerializeToString,
            vision__pb2.InferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopAutoInference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AIVisionPackage.AIVisionServiceGrpc/stopAutoInference',
            vision__pb2.EmptyRequest.SerializeToString,
            vision__pb2.CommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startPushInferenceResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/AIVisionPackage.AIVisionServiceGrpc/startPushInferenceResult',
            vision__pb2.EmptyRequest.SerializeToString,
            vision__pb2.InferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopPushInferenceResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AIVisionPackage.AIVisionServiceGrpc/stopPushInferenceResult',
            vision__pb2.EmptyRequest.SerializeToString,
            vision__pb2.CommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getCameraNumber(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AIVisionPackage.AIVisionServiceGrpc/getCameraNumber',
            vision__pb2.EmptyRequest.SerializeToString,
            vision__pb2.CameraNumberResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: audio.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61udio.proto\x12\x0c\x41udioPackage\"G\n\x0f\x41udioAsrRequest\x12\x11\n\tbegin_vad\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nd_vad\x18\x02 \x01(\x05\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\";\n\x10\x41udioAsrResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"3\n\x0f\x41udioTtsRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nvoice_type\x18\x02 \x01(\x05\"\x1f\n\x0f\x41udioNlpRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\";\n\x10\x41udioNlpResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\":\n\x10\x41udioFileRequest\x12\x12\n\naudio_name\x18\x01 \x01(\t\x12\x12\n\naudio_type\x18\x02 \x01(\x05\"*\n\x14\x41udioFileListRequest\x12\x12\n\naudio_type\x18\x01 \x01(\x05\"*\n\rAudioFileInfo\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0b\n\x03len\x18\x02 \x01(\x05\"^\n\x15\x41udioFileListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x05\x66iles\x18\x03 \x03(\x0b\x32\x1b.AudioPackage.AudioFileInfo\"P\n\x16ModifyAudioNameRequest\x12\x12\n\naudio_type\x18\x01 \x01(\x05\x12\x10\n\x08old_name\x18\x02 \x01(\t\x12\x10\n\x08new_name\x18\x03 \x01(\t\":\n\x10\x41udioPlayRequest\x12\x12\n\naudio_type\x18\x01 \x01(\x05\x12\x12\n\naudio_file\x18\x02 \x01(\t\"=\n\x13\x41udioRecordResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0b\n\x03len\x18\x03 \x01(\x05\")\n\x15\x41udioDirectionRequest\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\"B\n\x16\x41udioDirectionResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\r\n\x05\x61ngle\x18\x03 \x01(\x05\"\x13\n\x11\x41udioEmptyRequest\"0\n\x13\x41udioCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"I\n\x10\x41udioRmsResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\r\n\x05\x61ngle\x18\x03 \x01(\x05\x12\x0b\n\x03rms\x18\x04 \x01(\x05\x32\xd3\n\n\x10\x41udioServiceGrpc\x12N\n\x0bsetAudioAsr\x12\x1d.AudioPackage.AudioAsrRequest\x1a\x1e.AudioPackage.AudioAsrResponse\"\x00\x12Q\n\x0bsetAudioTts\x12\x1d.AudioPackage.AudioTtsRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12N\n\x0bsetAudioNlp\x12\x1d.AudioPackage.AudioNlpRequest\x1a\x1e.AudioPackage.AudioNlpResponse\"\x00\x12V\n\x0finsertAudioFile\x12\x1e.AudioPackage.AudioFileRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12V\n\x0f\x64\x65leteAudioFile\x12\x1e.AudioPackage.AudioFileRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12]\n\x10getAudioFileList\x12\".AudioPackage.AudioFileListRequest\x1a#.AudioPackage.AudioFileListResponse\"\x00\x12`\n\x13modifyAudioFileName\x12$.AudioPackage.ModifyAudioNameRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12T\n\rplayAudioFile\x12\x1e.AudioPackage.AudioPlayRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12\\\n\x14startRecordAudioFile\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12[\n\x13stopRecordAudioFile\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioRecordResponse\"\x00\x12U\n\rstopPlayAudio\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12\x62\n\x13getDirectionOfAudio\x12#.AudioPackage.AudioDirectionRequest\x1a$.AudioPackage.AudioDirectionResponse\"\x00\x12\\\n\x14\x65nableAudioDirection\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12]\n\x15\x64isableAudioDirection\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12R\n\rgetCurrentRms\x12\x1f.AudioPackage.AudioEmptyRequest\x1a\x1e.AudioPackage.AudioRmsResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'audio_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUDIOASRREQUEST._serialized_start=29
  _AUDIOASRREQUEST._serialized_end=100
  _AUDIOASRRESPONSE._serialized_start=102
  _AUDIOASRRESPONSE._serialized_end=161
  _AUDIOTTSREQUEST._serialized_start=163
  _AUDIOTTSREQUEST._serialized_end=214
  _AUDIONLPREQUEST._serialized_start=216
  _AUDIONLPREQUEST._serialized_end=247
  _AUDIONLPRESPONSE._serialized_start=249
  _AUDIONLPRESPONSE._serialized_end=308
  _AUDIOFILEREQUEST._serialized_start=310
  _AUDIOFILEREQUEST._serialized_end=368
  _AUDIOFILELISTREQUEST._serialized_start=370
  _AUDIOFILELISTREQUEST._serialized_end=412
  _AUDIOFILEINFO._serialized_start=414
  _AUDIOFILEINFO._serialized_end=456
  _AUDIOFILELISTRESPONSE._serialized_start=458
  _AUDIOFILELISTRESPONSE._serialized_end=552
  _MODIFYAUDIONAMEREQUEST._serialized_start=554
  _MODIFYAUDIONAMEREQUEST._serialized_end=634
  _AUDIOPLAYREQUEST._serialized_start=636
  _AUDIOPLAYREQUEST._serialized_end=694
  _AUDIORECORDRESPONSE._serialized_start=696
  _AUDIORECORDRESPONSE._serialized_end=757
  _AUDIODIRECTIONREQUEST._serialized_start=759
  _AUDIODIRECTIONREQUEST._serialized_end=800
  _AUDIODIRECTIONRESPONSE._serialized_start=802
  _AUDIODIRECTIONRESPONSE._serialized_end=868
  _AUDIOEMPTYREQUEST._serialized_start=870
  _AUDIOEMPTYREQUEST._serialized_end=889
  _AUDIOCOMMONRESPONSE._serialized_start=891
  _AUDIOCOMMONRESPONSE._serialized_end=939
  _AUDIORMSRESPONSE._serialized_start=941
  _AUDIORMSRESPONSE._serialized_end=1014
  _AUDIOSERVICEGRPC._serialized_start=1017
  _AUDIOSERVICEGRPC._serialized_end=2380
# @@protoc_insertion_point(module_scope)




#
class RangMode(object):
    """定义数据范围控制模式

    NORMAL: 正常
    ABSOLUTE: 绝对值
    OPPOSITE: 相反数
    """
    NORMAL = 0
    ABSOLUTE = 1
    OPPOSITE = 2
def num_normal(value, upper_limit, lower_limit, mode=RangMode.NORMAL):
    """规范化数值

            Args:
                value: 原始值
                upper_limit: 数值上限
                lower_limit: 数值下限
                mode (RangMode, optional): 规范模式. Defaults to RangMode.NORMAL.

            Returns:
                返回规范后的值. 如果 value 超出了 [lower_limit, upper_limit], 会被置为 lower_limit
                或 upper_limit, 然后根据 mode 进行改变, 例如:

                k = num_normal(5, 3, 4) # k = 5
                p = num_normal(5, 8, 10, RangMode.OPPOSITE) # p = -8
                n = num_normal(-5, -10, -6, RangMode.ABSOLUTE) # n = 6
            """
    # 确保 上限 不低于 下限
    if upper_limit < lower_limit:
        (upper_limit, lower_limit) = (lower_limit, upper_limit)

    if value > upper_limit:
        value = upper_limit
    if value < lower_limit:
        value = lower_limit
    if mode == RangMode.ABSOLUTE:
        value = abs(value)
    elif mode == RangMode.OPPOSITE:
        value = value * (-1)

    return value

import math
class _Color(object):
    color = 0

    def __init__(self, color=0):
        self.color = color

    def red(self):
        return (self.color & 0x00FF0000) >> 16

    def green(self):
        return (self.color & 0x0000FF00) >> 8

    def blue(self):
        return self.color & 0x000000FF


class Color(_Color):
    RED = _Color(0x00FF0000)
    ORANGE = _Color(0x00FF8000)
    YELLOW = _Color(0x00FFF000)
    GREEN = _Color(0x0000FF00)
    CYAN = _Color(0x0000FFFF)
    BLUE = _Color(0x000000FF)
    PURPLE = _Color(0x00FF00FF)
    BLACK = _Color(0x00000000)
    WHITE = _Color(0x00FFFFFF)
    GREY = _Color(0x00BEBEBE)

    Lights = {
        1 : RED,
        2 : ORANGE,
        3 : YELLOW,
        4 : GREEN,
        5 : CYAN,
        6 : BLUE,
        7 : PURPLE,
        8 : WHITE,
        9 : GREY,
    }

    """ 定义颜色类型

    Args:
        object ([type]): [description]
    """

    def __init__(self, color=0):
        super().__init__(color)

    @staticmethod
    def create_color_rgb(red: int, green: int, blue: int):
        """根据红, 绿, 蓝通道值创建颜色

        Args:
            red (int): 红通道值
            green (int): 绿通道值
            blue (int): 蓝通道值

        Returns:
            Color: 返回 Color 对象
        """
        v_red = num_normal(red, 255, 0)
        v_green = num_normal(green, 255, 0)
        v_blue = num_normal(blue, 255, 0)
        v = v_red << 16 | v_green << 8 | v_blue
        return Color(v)

    @staticmethod
    def __create_color_hsv(hue: int, saturation: int, value: int) -> _Color:
        """[summary]

        Args:
            hue (int): 色调值, 范围: [0, 360]
            saturation (int): 饱和度, 范围: [0, 100]
            value (int): 明度, 范围: [0, 100]
        """
        h = int(hue) % 360
        s = num_normal(saturation, 100, 0) * 0.01
        v = num_normal(value, 100, 0) * 0.01

        i = math.floor(h / 60)
        f = (h / 60) - i
        p = v * (1 - s)
        q = v * (1 - (s * f))
        t = v * (1 - (s * (1 - f)))

        if i == 0:
            rr = (v, t, p)
        elif i == 1:
            rr = (q, v, p)
        elif i == 2:
            rr = (p, v, t)
        elif i == 3:
            rr = (p, q, v)
        elif i == 4:
            rr = (t, p, v)
        else:
            rr = (v, p, q)

        result = Color.create_color_rgb(math.floor(rr[0] * 255),
                                        math.floor(rr[1] * 255),
                                        math.floor(rr[2] * 255))
        return result

    @staticmethod
    def create_color_hsv(hue_percent: int, saturation: int, value: int) -> _Color:
        p = num_normal(hue_percent, 100, 0)
        return Color.__create_color_hsv(int(p * 360 * 0.01), saturation, value)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import model_pb2 as model__pb2


class ModelServiceGrpcStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.modelCommonControl = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/modelCommonControl',
                request_serializer=model__pb2.ModelControlRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.mecanumMotorControl = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/mecanumMotorControl',
                request_serializer=model__pb2.MotorControlRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.mecanumXYZControl = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/mecanumXYZControl',
                request_serializer=model__pb2.XYZControlRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.mecanumStop = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/mecanumStop',
                request_serializer=model__pb2.MecanumStopRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.balanceKeepBalancing = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/balanceKeepBalancing',
                request_serializer=model__pb2.BalanceKeepBalancingRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.transformArmsControl = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/transformArmsControl',
                request_serializer=model__pb2.TransformArmsControlRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.transformSetHeight = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/transformSetHeight',
                request_serializer=model__pb2.TransformSetHeightRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.enableAdaptivePose = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/enableAdaptivePose',
                request_serializer=model__pb2.EnableAdaptivePoseRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.transformSetHeightByIncrement = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/transformSetHeightByIncrement',
                request_serializer=model__pb2.TransformSetHeightIncrementRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.wheelleggedRestory = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/wheelleggedRestory',
                request_serializer=model__pb2.WheelleggedRestoryRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.wheelleggedSetHeight = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/wheelleggedSetHeight',
                request_serializer=model__pb2.WheelleggedSetHeightRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.wheelleggedSetLeanAngle = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/wheelleggedSetLeanAngle',
                request_serializer=model__pb2.WheelleggedSetLeanAngleRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.setAcceleration = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/setAcceleration',
                request_serializer=model__pb2.SetAccelerationRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )
        self.resetAcceleration = channel.unary_unary(
                '/ModelPackage.ModelServiceGrpc/resetAcceleration',
                request_serializer=model__pb2.ResetAccelerationRequest.SerializeToString,
                response_deserializer=model__pb2.ModelCommonResponse.FromString,
                )


class ModelServiceGrpcServicer(object):
    """Missing associated documentation comment in .proto file."""

    def modelCommonControl(self, request, context):
        """模型通用运动控制
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def mecanumMotorControl(self, request, context):
        """麦轮车
        4个电机控制
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def mecanumXYZControl(self, request, context):
        """xyz控制
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def mecanumStop(self, request, context):
        """麦轮车停止
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def balanceKeepBalancing(self, request, context):
        """平衡车
        启动/停止小车并保持自平衡
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def transformArmsControl(self, request, context):
        """变形工程车
        变形车四个臂角度控制
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def transformSetHeight(self, request, context):
        """变形车底盘高度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enableAdaptivePose(self, request, context):
        """变形车开启/关闭自适应
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def transformSetHeightByIncrement(self, request, context):
        """变形车升高/降低底盘高度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def wheelleggedRestory(self, request, context):
        """轮腿
        轮腿恢复到初始高度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def wheelleggedSetHeight(self, request, context):
        """设置高度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def wheelleggedSetLeanAngle(self, request, context):
        """设置左右倾斜角度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setAcceleration(self, request, context):
        """加速度，目前只用于平衡车
        设置加速度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def resetAcceleration(self, request, context):
        """重置加速度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelServiceGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'modelCommonControl': grpc.unary_unary_rpc_method_handler(
                    servicer.modelCommonControl,
                    request_deserializer=model__pb2.ModelControlRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'mecanumMotorControl': grpc.unary_unary_rpc_method_handler(
                    servicer.mecanumMotorControl,
                    request_deserializer=model__pb2.MotorControlRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'mecanumXYZControl': grpc.unary_unary_rpc_method_handler(
                    servicer.mecanumXYZControl,
                    request_deserializer=model__pb2.XYZControlRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'mecanumStop': grpc.unary_unary_rpc_method_handler(
                    servicer.mecanumStop,
                    request_deserializer=model__pb2.MecanumStopRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'balanceKeepBalancing': grpc.unary_unary_rpc_method_handler(
                    servicer.balanceKeepBalancing,
                    request_deserializer=model__pb2.BalanceKeepBalancingRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'transformArmsControl': grpc.unary_unary_rpc_method_handler(
                    servicer.transformArmsControl,
                    request_deserializer=model__pb2.TransformArmsControlRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'transformSetHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.transformSetHeight,
                    request_deserializer=model__pb2.TransformSetHeightRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'enableAdaptivePose': grpc.unary_unary_rpc_method_handler(
                    servicer.enableAdaptivePose,
                    request_deserializer=model__pb2.EnableAdaptivePoseRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'transformSetHeightByIncrement': grpc.unary_unary_rpc_method_handler(
                    servicer.transformSetHeightByIncrement,
                    request_deserializer=model__pb2.TransformSetHeightIncrementRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'wheelleggedRestory': grpc.unary_unary_rpc_method_handler(
                    servicer.wheelleggedRestory,
                    request_deserializer=model__pb2.WheelleggedRestoryRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'wheelleggedSetHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.wheelleggedSetHeight,
                    request_deserializer=model__pb2.WheelleggedSetHeightRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'wheelleggedSetLeanAngle': grpc.unary_unary_rpc_method_handler(
                    servicer.wheelleggedSetLeanAngle,
                    request_deserializer=model__pb2.WheelleggedSetLeanAngleRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'setAcceleration': grpc.unary_unary_rpc_method_handler(
                    servicer.setAcceleration,
                    request_deserializer=model__pb2.SetAccelerationRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
            'resetAcceleration': grpc.unary_unary_rpc_method_handler(
                    servicer.resetAcceleration,
                    request_deserializer=model__pb2.ResetAccelerationRequest.FromString,
                    response_serializer=model__pb2.ModelCommonResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ModelPackage.ModelServiceGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelServiceGrpc(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def modelCommonControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/modelCommonControl',
            model__pb2.ModelControlRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def mecanumMotorControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/mecanumMotorControl',
            model__pb2.MotorControlRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def mecanumXYZControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/mecanumXYZControl',
            model__pb2.XYZControlRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def mecanumStop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/mecanumStop',
            model__pb2.MecanumStopRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def balanceKeepBalancing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/balanceKeepBalancing',
            model__pb2.BalanceKeepBalancingRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def transformArmsControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/transformArmsControl',
            model__pb2.TransformArmsControlRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def transformSetHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/transformSetHeight',
            model__pb2.TransformSetHeightRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enableAdaptivePose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/enableAdaptivePose',
            model__pb2.EnableAdaptivePoseRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def transformSetHeightByIncrement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/transformSetHeightByIncrement',
            model__pb2.TransformSetHeightIncrementRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def wheelleggedRestory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/wheelleggedRestory',
            model__pb2.WheelleggedRestoryRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def wheelleggedSetHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/wheelleggedSetHeight',
            model__pb2.WheelleggedSetHeightRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def wheelleggedSetLeanAngle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/wheelleggedSetLeanAngle',
            model__pb2.WheelleggedSetLeanAngleRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setAcceleration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/setAcceleration',
            model__pb2.SetAccelerationRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def resetAcceleration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ModelPackage.ModelServiceGrpc/resetAcceleration',
            model__pb2.ResetAccelerationRequest.SerializeToString,
            model__pb2.ModelCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import logging
import sys, os

sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import power_pb2, power_pb2_grpc
from base_client import GrpcClient

class PowerClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = power_pb2_grpc.PowerServiceGrpcStub(channel=self.channel)

    def getPowerValue(self):
        input_data = power_pb2.PowerRequest()
        response = self.client.getPowerValue(input_data)
        return response


import logging
import sys, os

sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import bluetooth_pb2, bluetooth_pb2_grpc
from base_client import GrpcClient

class BlueToothClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = bluetooth_pb2_grpc.BluetoothServiceGrpcStub(channel=self.channel)

    def getBtStatus(self):
        input_data = bluetooth_pb2.BtStatusRequest()
        response = self.client.getBtStatus(input_data)
        return response